This function selects columns to import from a data frame object. Its a general puporse function, so you can specify any columns to import. It returns a data frame with the specified columns.
select_cols(df = NULL, cols = NULL, ...) select_att(df = NULL, ...) select_att_mma(df = NULL, ...) select_prov(df = NULL, ...)
| df | a data frame |
|---|---|
| cols | character string with column names to import. |
| ... | Additional arguments passed to |
A data frame with selected columns to import.
select_cols is used to chop the attendance, mma attendance
and service log sheets in data frames:
select_att - chops attendance data frame
select_att_mma - chops MMA attendance data frame
select_prov - chops service provision
if (FALSE) { # select mpg form mtcars select_cols(mtcars, "mpg") # load sheets df attendance_df <- read_sheet("./data/attendance.csv") attendance2_df <- read_sheet("./data/attendance2.csv") service_provision_df <- read_sheet("./data/service provision.csv") # chop attendance select_att(attendance_df) # chop attendance 2 select_att_mma(attendance2_df) # chop service provision df select_prov(service_provision_df) }